{% extends "base.html" %}

{% block title %}Error - KenobiX Explorer{% endblock %}

{% block content %}
<article>
  <header>
    <h1>Error</h1>
  </header>
  <p>{{ message }}</p>
  <footer>
    <a href="/" role="button">Back to Home</a>
  </footer>
</article>
{% endblock %}
